{% extends "base.html" %}

{% block title %}
	Supplies &raquo; {{supply.id}} &raquo; Notes &raquo; {{note.index}} Edit
{% endblock %}

{% block nav %}
	<a href="/e/supplies">Supplies</a>  &raquo;
	<a href="/e/supplies/{{supply.id}}">{{supply.id}}</a>  &raquo;
	<a href="/e/supplies/{{supply.id}}/notes">Notes</a>  &raquo;
	{{note.index}} Edit
{% endblock %}

{% block content %}

	<form method="post">
		<fieldset>
			<legend>Update Supply Note</legend>
			Category {{input_text('category', note.category)}}
			Important? {{input_checkbox('is_important', note.is_important)}}
			{{input_textarea('body', note.body, 30, 80)}}
			<input type="submit" name="update" value="Update">
		</fieldset>
	</form>

	<form method="post">
		<fieldset>
			<legend>Delete Supply Note</legend>
			<input type="submit" name="delete" value="Delete">
		</fieldset>
	</form>

{% endblock %}
