{% extends "base.html" %}

{% block title %}
	LAF Imports &raquo; {{process_id}}
{% endblock %}

{% block nav %}
	<a href="/e/laf_imports">LAF Imports</a> &raquo; {{process_id}}
{% endblock %}

{% block content %}

	<h2>LAF Import</h2>

	{% if progress %}
		<p>{{progress}}.</p>
	{% endif %}

	{% if is_alive %}
			<p>Still running. Refresh the page to see latest progress.</p>
	{% else %}
			{% if error_message %}
					<p>
						The import has failed:
					</p>
					<pre>{{error_message}}</pre>
			{% else %}
					<p>The file has been imported successfully.</p>
			{% endif %}
	{% endif %}

{% endblock %}
