{% extends "base.html" %}

{% block title %}
	&raquo; Scenarios &raquo; {{scenario.name}}
{% endblock %}

{% block nav %}
	<a href="/e/scenarios">Scenarios</a> &raquo; {{scenario.name}} 
 	[<a href="/e/scenarios/{{scenario.id}}/edit">edit</a>]
{% endblock %}

{% block content %}
	<form action="/reports/247" method="post">
		<fieldset>
			<label>Site Codes</label><br>
			{{input_textarea('site_codes', '', 5, 40, placeholder='One on each line, includes all if left blank')}}    						
			<input type="hidden" name="scenario_id" value="{{scenario.id}}">
			<input type="submit" value="Run">
		</fieldset>	
	</form>

	<h2>Properties</h2>	

	<pre>{{scenario.properties}}</pre>

{% endblock %}
