{% extends "base.html" %}

{% block title %}
	&raquo; Supplier Contracts &raquo; {{contract.name}} &raquo; Batches
{% endblock %}

{% block nav %}
	<a href="/e/supplier_contracts">Supplier Contracts</a> &raquo; 
	<a href="/e/supplier_contracts/{{contract.id}}">{{contract.name}}</a> &raquo; 
	Batches [<a href="/e/supplier_contracts/{{contract.id}}/add_batch">add</a>]
{% endblock %}

{% block content %}
	<table>
		<caption>Batches</caption>	
		<thead>
			<tr>
				<th>Reference</th>
				<th>Description</th>
			</tr>
		</thead>
		<tbody>
			{% for batch in batches %}
				<tr>
					<td>
						<a href="/e/supplier_batches/{{batch.id}}?bill_limit=1000"
							>{{batch.reference}}</a>
					</td>
					<td>{{batch.description}}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>
{% endblock %}
