{% extends "base.html" %}

{% block title %}
	&raquo; DTC Meter Types
{% endblock %}

{% block nav %}
	DTC Meter Types
{% endblock %}

{% block content %}

	<table>
		<thead>
			<tr>
				<th>Code</th>
				<th>Description</th>
			</tr>
		</thead>
		<tbody>
			{% for code, desc in dtc_meter_types.items() %}
				<tr>
					<td><a href="/e/dtc_meter_types/{{code}}">{{code}}</a></td>
					<td>{{desc}}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>

{% endblock %}
